Enum rustc_ap_rustc_target::spec::SplitDebuginfo [−][src]
pub enum SplitDebuginfo {
Off,
Packed,
Unpacked,
}Variants
Split debug-information is disabled, meaning that on supported platforms you can find all debug information in the executable itself. This is only supported for ELF effectively.
- Windows - not supported
- macOS - don’t run
dsymutil - ELF -
.dwarf_*sections
Split debug-information can be found in a “packed” location separate from the final artifact. This is supported on all platforms.
- Windows -
*.pdb - macOS -
*.dSYM(rundsymutil) - ELF -
*.dwp(runrust-llvm-dwp)
Split debug-information can be found in individual object files on the filesystem. The main executable may point to the object files.
- Windows - not supported
- macOS - supported, scattered object files
- ELF - supported, scattered
*.dwofiles